@@ -13,7 +13,7 @@ class Constants:
 	ENVIRONMENTS = ['DEV', 'STAGE', 'PROD']
 	MAX_HASH_VALUE = math.pow(2, 32)
 	TOTAL_THREE_DECIMAL_TRAFFIC = 100000
-	DATA_REFRESH_INTERVAL = 5 * 60
+	DATA_REFRESH_INTERVAL = 60
 	CAPTURE_EVENTS_FLAG = True
 	EVENT_FLUSH_INITIAL_DELAY = 2 * 60
 	EVENT_FLUSH_INTERVAL = 5 * 60
